[dts] [PATCH] framework/crb: fix typos

Rami Rosen ramirose at gmail.com
Tue Jan 15 07:43:52 CET 2019


This patch fixes the following typos in framework/crb.py:
useage->usage
addtional->additional

Signed-off-by: Rami Rosen <ramirose at gmail.com>
---
 framework/crb.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/framework/crb.py b/framework/crb.py
index a6eb69e..e15fd77 100644
--- a/framework/crb.py
+++ b/framework/crb.py
@@ -92,7 +92,7 @@ class Crb(object):
 
     def create_session(self, name=""):
         """
         Create new session for addtional useage. This session will not enable log.
         """
         logger = getLogger(name)
         session = SSHConnection(self.get_ip_address(),
@@ -106,7 +106,7 @@ class Crb(object):
 
     def destroy_session(self, session=None):
         """
-        Destroy addtional session.
+        Destroy additional session.
         """
         for save_session in self.sessions:
             if save_session == session:
@@ -552,7 +552,7 @@ class Crb(object):
 
         cpuinfo = cpuinfo.split()
         # haswell cpu on cottonwood core id not correct
         # need addtional coremap for haswell cpu
         core_id = 0
         coremap = {}
         for line in cpuinfo:
@@ -92,7 +92,7 @@ class Crb(object):
     def create_session(self, name=""):
         """
-        Create new session for addtional useage. This session will not enable log.
+        Create new session for additional usage. This session will not enable log.
         """
         logger = getLogger(name)
@@ -552,7 +552,7 @@ class Crb(object):
         cpuinfo = cpuinfo.split()
         # haswell cpu on cottonwood core id not correct
-        # need addtional coremap for haswell cpu
+        # need additional coremap for haswell cpu
         core_id = 0
         coremap = {}
-- 
1.8.3.1



More information about the dts mailing list